@@ -19,17 +19,16 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 import dataclasses
 import os
-from os.path import splitext, join as path_join
+from os.path import splitext
 from urllib.parse import quote, urlparse
 from collections import defaultdict
 from enum import Enum, Flag, auto
 import random
 from binascii import hexlify
 from typing import Optional, Iterator, Tuple, List, Callable, Union, Iterable, Type
-from asyncio import Event
 import json
+from importlib.resources import files
 
-from pkg_resources import resource_filename
 from httpx import ReadTimeout, RequestError
 
 from wapitiCore.definitions import FindingBase
@@ -192,7 +191,7 @@ class Attack:
     # Must be defined in the code of the module
     require = []
 
-    DATA_DIR = resource_filename("wapitiCore", os.path.join("data", "attacks"))
+    DATA_DIR = str(files("wapitiCore").joinpath("data", "attacks"))
     HOME_DIR = os.getenv("HOME") or os.getenv("USERPROFILE") or "home"
 
     # Color codes
@@ -218,20 +217,18 @@ class Attack:
 
     @staticmethod
     def get_resource(resource_path: str):
-        return resource_filename("wapitiCore", path_join("data", "attacks", resource_path))
+        return str(files("wapitiCore").joinpath("data", "attacks", resource_path))
 
     def __init__(
             self,
             crawler: AsyncCrawler,
             persister: SqlPersister,
             attack_options: dict,
-            stop_event: Event,
             crawler_configuration: CrawlerConfiguration):
         super().__init__()
         self._session_id = "".join([random.choice("0123456789abcdefghjijklmnopqrstuvwxyz") for __ in range(0, 6)])
         self.crawler = crawler
         self.persister = persister
-        self._stop_event = stop_event
         self.options = attack_options
         self.crawler_configuration = crawler_configuration
         self.start = 0
@@ -247,6 +244,7 @@ class Attack:
         # Must be left empty in the code
         self.deps = []
 
+    # pylint: disable=too-many-positional-arguments
     async def add_payload(self, finding_class: Type[FindingBase], request_id: int = -1,
                           level: int = 0, request: Request = None, parameter: str = "", info: str = "",
                           response: Response = None):
@@ -264,26 +262,31 @@ class Attack:
         )
 
     # Define explicit wrapper functions for each severity level
+    # pylint: disable=too-many-positional-arguments
     async def add_info(self, finding_class: Type[FindingBase], request_id: int = -1,
                        request: Optional[Request] = None, parameter: str = "",
                        info: str = "", response: Optional[Response] = None):
         await self.add_payload(finding_class, request_id, INFO_LEVEL, request, parameter, info, response)
 
+    # pylint: disable=too-many-positional-arguments
     async def add_low(self, finding_class: Type[FindingBase], request_id: int = -1,
                       request: Optional[Request] = None, parameter: str = "",
                       info: str = "", response: Optional[Response] = None):
         await self.add_payload(finding_class, request_id, LOW_LEVEL, request, parameter, info, response)
 
+    # pylint: disable=too-many-positional-arguments
     async def add_medium(self, finding_class: Type[FindingBase], request_id: int = -1,
                          request: Optional[Request] = None, parameter: str = "",
                          info: str = "", response: Optional[Response] = None):
         await self.add_payload(finding_class, request_id, MEDIUM_LEVEL, request, parameter, info, response)
 
+    # pylint: disable=too-many-positional-arguments
     async def add_high(self, finding_class: Type[FindingBase], request_id: int = -1,
                        request: Optional[Request] = None, parameter: str = "",
                        info: str = "", response: Optional[Response] = None):
         await self.add_payload(finding_class, request_id, HIGH_LEVEL, request, parameter, info, response)
 
+    # pylint: disable=too-many-positional-arguments
     async def add_critical(self, finding_class: Type[FindingBase], request_id: int = -1,
                            request: Optional[Request] = None, parameter: str = "",
                            info: str = "", response: Optional[Response] = None):
@@ -371,6 +374,7 @@ class Attack:
 
 
 class Mutator:
+    # pylint: disable=too-many-positional-arguments
     def __init__(
             self, methods="FGP", qs_inject=False, max_queries_per_pattern: int = 1000,
             parameters=None,  # Restrict attack to a whitelist of parameters
@@ -588,6 +592,9 @@ class Mutator:
             data = json.loads(request.post_params)
         except json.JSONDecodeError:
             return
+        except TypeError:
+            # we may bump into POST/PUT/etc requests without body
+            return
 
         get_params = request.get_params
         referer = request.referer
