@@ -38,10 +38,10 @@ class ModuleCrlf(Attack):
     MSG_VULN = "CRLF Injection"
     do_get = True
     do_post = True
-    payloads = [PayloadInfo(payload="http://www.google.fr\r\nwapiti: 3.2.0 version")]
+    payloads = [PayloadInfo(payload="http://www.google.fr\r\nwapiti: 3.2.4 version")]
 
-    def __init__(self, crawler, persister, attack_options, stop_event, crawler_configuration):
-        super().__init__(crawler, persister, attack_options, stop_event, crawler_configuration)
+    def __init__(self, crawler, persister, attack_options, crawler_configuration):
+        super().__init__(crawler, persister, attack_options, crawler_configuration)
         self.mutator = self.get_mutator()
 
     async def attack(self, request: Request, response: Optional[Response] = None):
@@ -49,7 +49,7 @@ class ModuleCrlf(Attack):
 
         for mutated_request, parameter, _payload in self.mutator.mutate(
                 request,
-                str_to_payloadinfo(["http://www.google.fr\r\nwapiti: 3.2.0 version"]),
+                str_to_payloadinfo(["http://www.google.fr\r\nwapiti: 3.2.4 version"]),
         ):
             log_verbose(f"[¨] {mutated_request.url}")
 
