@@ -104,8 +104,8 @@ class ModuleFile(Attack):
     """Detect file-related vulnerabilities such as directory traversal and include() vulnerabilities."""
     name = "file"
 
-    def __init__(self, crawler, persister, attack_options, stop_event, crawler_configuration):
-        Attack.__init__(self, crawler, persister, attack_options, stop_event, crawler_configuration)
+    def __init__(self, crawler, persister, attack_options, crawler_configuration):
+        Attack.__init__(self, crawler, persister, attack_options, crawler_configuration)
         self.known_false_positives = defaultdict(set)
         self.mutator = self.get_mutator()
 
@@ -134,11 +134,11 @@ class ModuleFile(Attack):
             self.network_errors += 1
             # Can't check out, avoid false negative
             return False
-        else:
-            if pattern in response.content:
-                # Store false positive information in order to prevent doing unnecessary requests
-                self.known_false_positives[request.path_id].add(pattern)
-                return True
+
+        if pattern in response.content:
+            # Store false positive information in order to prevent doing unnecessary requests
+            self.known_false_positives[request.path_id].add(pattern)
+            return True
 
         return False
 
