@@ -35,7 +35,8 @@ from wapitiCore.main.banners import print_banner
 from wapitiCore.parsers.commandline import parse_args
 from wapitiCore.main.log import logging
 from wapitiCore.net.classes import HttpCredential, FormCredential, RawCredential
-from wapitiCore.net.auth import async_try_form_login, load_form_script, check_http_auth, login_with_raw_data
+from wapitiCore.net.auth import (async_try_form_login, load_form_script, check_http_auth, login_with_raw_data,
+                                 authenticate_with_side_file)
 from wapitiCore.net import Request
 from wapitiCore.report import GENERATORS
 from wapitiCore.parsers.swagger import Swagger
@@ -43,16 +44,11 @@ from wapitiCore.parsers.swagger import Swagger
 global_stop_event = asyncio.Event()
 
 
-def inner_ctrl_c_signal_handler():
+def inner_ctrl_c_signal_handler(_, __):
     logging.info("Waiting for running crawler tasks to finish, please wait.")
     global_stop_event.set()
 
 
-def stop_attack_process():
-    logging.info("Waiting for all payload tasks to finish for current resource, please wait.")
-    global_stop_event.set()
-
-
 def fix_url_path(url: str):
     """Fix the url path if it's not defined"""
     return url if urlparse(url).path else url + '/'
@@ -65,9 +61,10 @@ def is_valid_url(url: str):
     except ValueError:
         logging.error('ValueError')
         return False
-    else:
-        if parts.scheme in ("http", "https") and parts.netloc:
-            return True
+
+    if parts.scheme in ("http", "https") and parts.netloc:
+        return True
+
     logging.error(f"Error: {url} is not a valid URL")
     return False
 
@@ -79,12 +76,13 @@ def is_valid_endpoint(url_type, url: str):
     except ValueError:
         logging.error('ValueError')
         return False
-    else:
-        if parts.params or parts.query or parts.fragment:
-            logging.error(f"Error: {url_type} must not contain params, query or fragment!")
-            return False
-        if parts.scheme in ("http", "https") and parts.netloc:
-            return True
+
+    if parts.params or parts.query or parts.fragment:
+        logging.error(f"Error: {url_type} must not contain params, query or fragment!")
+        return False
+    if parts.scheme in ("http", "https") and parts.netloc:
+        return True
+
     logging.error(f"Error: {url_type} must contain scheme and host")
     return False
 
@@ -92,6 +90,7 @@ def is_valid_endpoint(url_type, url: str):
 def is_mod_cms_set(args):
     if args.modules and "cms" in args.modules:
         return True
+
     logging.error("Error: Invalid option --cms, module cms is required when this option is used")
     return False
 
@@ -120,6 +119,7 @@ def ping(url: str):
     return True
 
 
+# pylint: disable=too-many-locals,too-many-branches,too-many-statements
 async def wapiti_main():
     print_banner()
     args = parse_args()
@@ -196,13 +196,17 @@ async def wapiti_main():
             raise
 
     if args.swagger_uri:
-        swagger = Swagger(swagger_url=args.swagger_uri, base_url=url)
+        swagger = Swagger(swagger_url=args.swagger_uri, base_url=url, crawler_configuration=wap.crawler_configuration)
         nb_out = 0
-        for request in swagger.get_requests():
-            if wap.target_scope.check(request):
-                wap.add_start_url(request)
-            else:
-                nb_out += 1
+        try:
+            for request in await swagger.get_requests():
+                if wap.target_scope.check(request):
+                    wap.add_start_url(request)
+                else:
+                    nb_out += 1
+        except (ValueError, FileNotFoundError, RuntimeError) as exception:
+            raise InvalidOptionValue("--swagger", f"Could not parse swagger file: {exception}") from exception
+
         if nb_out > 0:
             logging.warning(f"[!] {nb_out} out of scope requests from the Swagger file are not added.")
 
@@ -212,8 +216,8 @@ async def wapiti_main():
                 wap.add_start_url(Request(start_url))
             elif os.path.isfile(start_url):
                 try:
-                    with codecs.open(start_url, encoding="UTF-8") as urlfd:
-                        for urlline in urlfd:
+                    with codecs.open(start_url, encoding="UTF-8") as url_fd:
+                        for urlline in url_fd:
                             urlline = urlline.strip()
                             if urlline.startswith(("http://", "https://")):
                                 wap.add_start_url(Request(urlline))
@@ -235,6 +239,12 @@ async def wapiti_main():
         wap.set_headless(args.headless)
         wap.set_wait_time(args.wait_time)
 
+        if "side_file" in args:
+            if os.path.isfile(args.side_file):
+                wap.crawler_configuration.cookies = await authenticate_with_side_file(
+                    wap.crawler_configuration, args.side_file, args.headless
+                )
+
         if "cookie" in args:
             if os.path.isfile(args.cookie):
                 wap.set_cookie_file(args.cookie)
@@ -258,7 +268,7 @@ async def wapiti_main():
             wap.set_http_credentials(HttpCredential(args.http_user, args.http_password, args.auth_method))
 
         if ("http_user" in args and "http_password" not in args) or \
-           ("http_user" not in args and "http_password" in args):
+                ("http_user" not in args and "http_password" in args):
             raise InvalidOptionValue("--auth-user and --auth-password",
                                      "Both options are required when one is used")
 
@@ -411,14 +421,13 @@ async def wapiti_main():
                 "This option is required when --form-user and --form-password or form-cred is used")
         # This option is deprecated, but we still support it
         # Should be removed in the future
-        username, password = None, None
         if "%" in args.form_credentials:
             username, password = args.form_credentials.split("%", 1)
             form_credential = FormCredential(
-            username,
-            password,
-            args.form_url,
-        )
+                username,
+                password,
+                args.form_url,
+            )
         else:
             raise InvalidOptionValue("--form-cred", args.form_credentials)
     elif "form_user" in args and "form_password" in args:
@@ -462,8 +471,6 @@ async def wapiti_main():
         for url in excluded_urls:
             wap.add_excluded_url(url)
 
-    loop = asyncio.get_event_loop()
-
     try:
         if not args.skip_crawl:
             if await wap.have_attacks_started() and not args.resume_crawl:
@@ -473,10 +480,12 @@ async def wapiti_main():
                     logging.info("[*] Resuming scan from previous session, please wait")
 
                 await wap.load_scan_state()
-                loop.add_signal_handler(signal.SIGINT, inner_ctrl_c_signal_handler)
-                await wap.browse(global_stop_event, parallelism=args.tasks)
-                loop.remove_signal_handler(signal.SIGINT)
-                await wap.save_scan_state()
+                signal.signal(signal.SIGINT, inner_ctrl_c_signal_handler)
+                try:
+                    await wap.browse(global_stop_event, parallelism=args.tasks)
+                finally:
+                    signal.signal(signal.SIGINT, signal.SIG_DFL)
+                    await wap.save_scan_state()
 
         if args.max_parameters:
             count = await wap.persister.remove_big_requests(args.max_parameters)
@@ -485,9 +494,7 @@ async def wapiti_main():
             )
 
         logging.info(f"[*] Wapiti found {await wap.count_resources()} URLs and forms during the scan")
-        loop.add_signal_handler(signal.SIGINT, stop_attack_process)
-        await wap.attack(global_stop_event)
-        loop.remove_signal_handler(signal.SIGINT)
+        await wap.attack()
 
     except OperationalError:
         logging.error(
